# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/interval.proto

require 'google/protobuf'

require 'google/protobuf/timestamp_pb'


descriptor_data = "\n\x1agoogle/type/interval.proto\x12\x0bgoogle.type\x1a\x1fgoogle/protobuf/timestamp.proto\"h\n\x08Interval\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBi\n\x0f\x63om.google.typeB\rIntervalProtoP\x01Z<google.golang.org/genproto/googleapis/type/interval;interval\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3"

pool = ::Google::Protobuf::DescriptorPool.generated_pool
pool.add_serialized_file(descriptor_data)

module Google
  module Type
    Interval = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.type.Interval").msgclass
  end
end

#### Source proto file: google/type/interval.proto ####
#
# // Copyright 2025 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.type;
#
# import "google/protobuf/timestamp.proto";
#
# option cc_enable_arenas = true;
# option go_package = "google.golang.org/genproto/googleapis/type/interval;interval";
# option java_multiple_files = true;
# option java_outer_classname = "IntervalProto";
# option java_package = "com.google.type";
# option objc_class_prefix = "GTP";
#
# // Represents a time interval, encoded as a Timestamp start (inclusive) and a
# // Timestamp end (exclusive).
# //
# // The start must be less than or equal to the end.
# // When the start equals the end, the interval is empty (matches no time).
# // When both start and end are unspecified, the interval matches any time.
# message Interval {
#   // Optional. Inclusive start of the interval.
#   //
#   // If specified, a Timestamp matching this interval will have to be the same
#   // or after the start.
#   google.protobuf.Timestamp start_time = 1;
#
#   // Optional. Exclusive end of the interval.
#   //
#   // If specified, a Timestamp matching this interval will have to be before the
#   // end.
#   google.protobuf.Timestamp end_time = 2;
# }
